<?php 
defined( 'JPATH_BASE' ) or die( 'Restricted access' );

use LMS\Libraries\Config\ConfigLoader;

class JLMSSystemExtension
{

    private static $_config;
   
    /***************** CONFIG SECTION ****************/
    public static function getConfigParam( $param_name = '' )
    {
        if(is_null(self::$_config))
        {
            self::$_config = new ConfigLoader('config.lms_extensions.json');
        }
        return self::$_config->getConfigParam($param_name);
    }


    /****************** CHECK SECTION ********************/
    public static function checkTemplatesSection()
    {
        $result = new stdClass();
        $templates = self::getConfigParam('templates');
        if (sizeof($templates))
        {
            foreach($templates as $template)
            {
                $isset_in_extensions = JLMSSystemExtension::checkInExtensions($template, 'template');
                if ($isset_in_extensions)
                {
                    $result->success[] = $template.' template status: OK';
                }else
                {
                    $result->errors[] = $template.' template status: Not found, please install or enable extension!';
                }

                $isset_in_styles = JLMSSystemExtension::checkTemplateInStyles($template);
                if ($isset_in_styles)
                {
                    $result->success[] = $template.' template style status: OK';
                }else
                {
                    $result->errors[] = $template.' template style status: Not found!';
                }
            }
        }
        return $result;
    }

    public static function checkInExtensions($template = '',$type='')
    {
        if (!$template) return false;
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('`extension_id`');
        $query->from('`#__extensions`');
        $query->where('`element`='.$db->quote($template));
        $query->where('`type`= "'.$type.'"');
        $query->where('`enabled`= 1');
        $db->setQuery($query);
        return  $db->loadResult();
    }

    public static function checkTemplateInStyles($template = '')
    {
        if (!$template) return false;
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('`id`');
        $query->from('`#__template_styles`');
        $query->where('`template`='.$db->quote($template));
        $db->setQuery($query);
        return  $db->loadResult();
    }

    public static function checkPluginsSection()
    {
        $result = new stdClass();
        $plugins = self::getConfigParam('plugins');
        if (sizeof($plugins))
        {
            foreach($plugins as $plugin)
            {
                $isset_in_extensions = JLMSSystemExtension::checkInExtensions($plugin,'plugin');
                if ($isset_in_extensions)
                {
                    $result->success[] = $plugin.' plugin status: OK';
                }else
                {
                    $result->errors[] = $plugin.' plugin status: Not found, please install or enable extension!';
                }
            }
        }
        return $result;
    }

    public static function checkModulesSection()
    {
        $result = new stdClass();
        $modules = self::getConfigParam('modules');
        if (sizeof($modules))
        {
            foreach($modules as $module=>$module_params)
            {

                $isset_in_extensions = JLMSSystemExtension::checkInExtensions($module,'module');
                if ($isset_in_extensions)
                {
                   $result->success[] = $module.' module status: OK';
                }else
                {
                   $result->errors[] = $module.' module status: Not found, please install or enable extension!';
                }
                if(isset($module_params['position']))
                {
                    $position = $module_params['position'];
                    $isset_in_position = JLMSSystemExtension::checkInModulesPosition($module,$position);
                    if ($isset_in_position)
                    {
                        $result->success[] = $module.' module assignment to '.$position.': OK';

                        $status = JLMSSystemExtension::getModuleStatus($isset_in_position);
                        if ($status==-2)
                        {
                            $isset_in_position = JLMSSystemExtension::createModule($module,$position);
                            $result->success[] = $module.' module assignment to '.$position.': Created';
                        }else
                        if ($status==0)
                        {
                            JLMSSystemExtension::setModuleStatus($isset_in_position,1);
                            $result->success[] = $module.' module assignment to '.$position.': Updated';
                        }

                    }else
                    {
                        $isset_in_position = JLMSSystemExtension::createModule($module,$position);
                        if ($isset_in_position)
                        {
                            $result->success[] = $module.' module assignment to '.$position.': Created';
                        }else
                        {
                            $result->errors[] = $module.' module assignment status: Error';
                        }
                    }

                }
                if(isset($module_params['pages']) && $isset_in_position)
                {
                    if ($module_params['pages']=='all')
                    {
                        JLMSSystemExtension::setModuleOnAllPages($isset_in_position);
                    }
                }


            }
        }
        return $result;
    }

    public static function setModuleOnAllPages($module_id=0)
    {
        $db = JFactory::getDbo();

        $db->setQuery('DELETE FROM `#__modules_menu` WHERE `moduleid`='.$module_id);
        $db->execute();

        $db->setQuery('INSERT INTO `#__modules_menu` SET `menuid`=0, `moduleid`='.$module_id);
        return $db->execute();
    }

    public static function setModuleStatus($module_id=0,$status=0)
    {
        $modules_table = JTable::getInstance('Module');
        $modules_table->load($module_id);
        $modules_table->published = $status;
        return $modules_table->store();
    }

    public static function getModuleStatus($module_id=0)
    {
        $modules_table = JTable::getInstance('Module');
        $modules_table->load($module_id);
        return $modules_table->published;
    }

    public static function createModule($module, $position)
    {
        $modules_table = JTable::getInstance('Module');
        $data = array(
            'id' => 0,
            'title' => $module,
            'module' => $module,
            'showtitle' => 1,
            'published' => 1,
            'position' => $position,
            'language' =>'*'
        );
        if (!$modules_table->bind($data))
        {
            print_R($modules_table->getError());
            return false;
        }

        if (!$modules_table->store())
        {
            print_R($modules_table->getError());
            return false;
        }
        return $modules_table->id;
    }

    public static function checkInModulesPosition($module,$position)
    {
        if (!$position) return false;
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('`id`');
        $query->from('`#__modules`');
        $query->where('`module`='.$db->quote($module));
        $query->where('`position`='.$db->quote($position));
        $query->order('`published` DESC');
        $db->setQuery($query);

        return  $db->loadResult();
    }

    /************************* ****************************/

//end JLMSSystemMenu class
}
?>