<?php
/**
 * User: nester_a
 * Date: 25.11.13
 */

namespace LMS\Tools\Conference\Service;

use LMS\Libraries\Base;
use LMS\Tools\Conference\Repositories;
use LMS\Libraries\Date;

require_once(_JOOMLMS_FRONT_HOME . DS . "includes" . DS . "classes" . DS . "lms.pagination.php");

class View extends Base\Service
{

	/**
	 * @var Date\Handler
	 */
	protected $dateHandler;

	public function __construct($options = array())
	{
		parent::__construct($options);
		$this->dateHandler = new Date\Handler();
	}

    public function getTeachersList($teachers, $filterTeacher)
    {
        return $this->prepareSubmitSelectBox($teachers, $filterTeacher, 'filter_teacher', ' - Select a teacher - ');
    }

    public function getStudentsList($students, $filterStudent)
    {
        return $this->prepareSubmitSelectBox($students, $filterStudent, 'filter_stu', ' - Select a student - ');
    }

	/**
	 * @param Repositories\Course $courseRepository
	 * @param $courseID
	 * @param $filters
	 * @return array
	 */
	public function getLists($courseRepository, $courseID, $filters)
    {
        $lists = array();

        $teachers = $courseRepository->getTeachers($courseID);
        $lists['filter_teach'] = $this->getTeachersList($teachers, $filters['teacher']);

        $students = $courseRepository->getStudents($courseID);
        $lists['filter_stu'] = $this->getStudentsList($students, $filters['student']);

        return $lists;
    }

    public function getDateTimeLists($values = array())
    {
        $lists = array();
        $times = $this->generateFormattedHours();
        $minutes = $this->generateFormattedMinutes();

        $fromHour = !empty($values) ? $this->dateHandler->getDatetime("H", $values['fromTime']) : 0;
        $fromMinutes = !empty($values) ?  $this->dateHandler->getDatetime("i", $values['fromTime']) : 0;
        $toHour = !empty($values) ?  $this->dateHandler->getDatetime("H", $values['toTime']) : 0;
        $toMinutes = !empty($values) ?  $this->dateHandler->getDatetime("i", $values['toTime']) : 0;

        $lists['from_hour'] = $this->prepareSelectBox($times, $fromHour, 'from_hour');
        $lists['to_hour'] = $this->prepareSelectBox($times,  $toHour, 'to_hour');
        $lists['from_minutes'] = $this->prepareSelectBox($minutes, $fromMinutes, 'from_min');
        $lists['to_minutes'] = $this->prepareSelectBox($minutes, $toMinutes, 'to_min');

        return $lists;
    }

    public function getTimeList()
    {
        $lists = array();
        $times = $this->generateFormattedHours();
        $minutes = $this->generateFormattedMinutes();
        $lists['time'] = $this->prepareSelectBox($times, 0, 'time');
        $lists['minutes'] = $this->prepareSelectBox($minutes, 0, 'minutes');

        return $lists;
    }


    public function getPageNavigation($total, $start, $count)
    {
        return new \JLMSPageNav($total, $start, $count );
    }

    /**
     * Prepare JLMS-like style select box
     *
     * @param array $optionsList
     * @param int $filter
     * @param string $selectBoxName
     * @return mixed
     */
    public function prepareSelectBox($optionsList, $filter, $selectBoxName)
    {
        return \mosHTML::selectList($optionsList, $selectBoxName, 'class="inputbox" size="1" ', 'value', 'text', $filter );
    }

    /**
     * Prepare JLMS-like style select box that submit form on change
     *
     * @param array $optionsList
     * @param int $filter
     * @param string $selectBoxName
     * @param string $selectBoxDefaultText
     * @return mixed
     */
    public function prepareSubmitSelectBox($optionsList, $filter, $selectBoxName, $selectBoxDefaultText)
    {
        $selectBox = array();
        $selectBox[] = \mosHTML::makeOption( 0, $selectBoxDefaultText);
        $i = 1;
        foreach ($optionsList as $option){
            $selectBox[] = \mosHTML::makeOption( $option->value, $option->text );
            $i++;
        }
        $javascript = 'onchange="document.adminForm.submit();"';
        return \mosHTML::selectList($selectBox, $selectBoxName, 'class="inputbox" size="1" '.$javascript, 'value', 'text', $filter );
    }

    /**
     * @param $params
     * @return array
     */
    public function prepareYesNoLists($params)
    {
        $lists = array();
        foreach($params as $name=>$value){
            $lists[$name] = $this->prepareYesNoList($name, $value);
        }

        return $lists;
    }

    /**
     * @param $name
     * @param $value
     * @return mixed|string
     */
    public function prepareYesNoList($name, $value)
    {
        return \mosHTML::yesnoRadioList( $name, 'class="inputbox" ', $value);
    }



    /**
     * @param $hours
     * @param $minutes
     * @param $date
     * @return int
     */
    public function prepareDate($hours, $minutes, $date)
    {
		$hours = strlen($hours) == 1 ? '0'.$hours : $hours;
		$minutes = strlen($minutes) == 1 ? '0'.$minutes : $minutes;
        return $this->dateHandler->getTimestamp(JLMS_dateToDB($date) . ' '.$hours.':'.$minutes.':00', $this->dateHandler->getTimezoneName());
    }


    public function prepareUsernames($users, $useGlobalGroups)
    {
        foreach($users as &$user) {
            $user->username = $user->name . ' ('.$user->username.')';
            if (!$useGlobalGroups) {
                $user->username = ($user->ug_name ? ($user->ug_name.' - ') :'' ) . $user->username;
            }
        }

        return $users;
    }

	/**
	 * @param $params
	 * @return array
	 */
	public function prepareUTCTimes($params)
	{
		$times = array();

		$times['fromTime'] = $this->dateHandler->getUTCDatetime('Y-m-d\TH:i:s', $params['daytime_from']);
		$times['toTime'] = $this->dateHandler->getUTCDatetime('Y-m-d\TH:i:s', $params['daytime_to']);

		return $times;
	}

    /**
     * Generate formmateed hours
     *
     * @return array
     */
    protected function generateFormattedHours()
    {
        $hours = array();
        for($i=0;$i<24;$i++)
        {
            $hours[$i] = new \stdClass();
            $hours[$i]->value = $i;
            if($i<10){
                $hours[$i]->text = '0'.$i;
            }
            else{
                $hours[$i]->text = $i;
            }
        }
        return $hours;
    }

    /**
     * Generate formatted minutes
     * @return array
     */
    protected function generateFormattedMinutes()
    {
        $minutes = array();
        for($i=0;$i<4;$i++)
        {
            $minutes[$i] = new \stdClass();
            $minutes[$i]->value = $i*15;
            if($i==0){
                $minutes[$i]->text = '00';
            }
            else{
                $minutes[$i]->text = $i*15;
            }
        }
        return $minutes;
    }


}